# DO NOT EDIT — generated from registry/*.yaml by `npm run generate-static`
"""Static TTS pricing data for the PriceToken SDK."""

from __future__ import annotations

from .types import FreshnessInfo, TtsModelPricing

STATIC_TTS_PRICING: list[TtsModelPricing] = [
    TtsModelPricing(
        model_id="amazon-polly-generative",
        provider="amazon",
        display_name="Amazon Polly Generative",
        cost_per_m_chars=30,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-05-08",
    ),
    TtsModelPricing(
        model_id="amazon-polly-govcloud-neural",
        provider="amazon",
        display_name="Amazon Polly GovCloud Neural",
        cost_per_m_chars=19.2,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2020-11-23",
    ),
    TtsModelPricing(
        model_id="amazon-polly-govcloud-standard",
        provider="amazon",
        display_name="Amazon Polly GovCloud Standard",
        cost_per_m_chars=4.8,
        voice_type="standard",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2018-02-28",
    ),
    TtsModelPricing(
        model_id="amazon-polly-long-form",
        provider="amazon",
        display_name="Amazon Polly Long-Form",
        cost_per_m_chars=100,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-11-16",
    ),
    TtsModelPricing(
        model_id="amazon-polly-neural",
        provider="amazon",
        display_name="Amazon Polly Neural",
        cost_per_m_chars=16,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2019-07-30",
    ),
    TtsModelPricing(
        model_id="amazon-polly-standard",
        provider="amazon",
        display_name="Amazon Polly Standard",
        cost_per_m_chars=4,
        voice_type="standard",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2016-11-30",
    ),
    TtsModelPricing(
        model_id="azure-custom-deprecated",
        provider="azure",
        display_name="Azure Custom TTS (Deprecated)",
        cost_per_m_chars=6,
        voice_type="standard",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="deprecated",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2018-11-01",
    ),
    TtsModelPricing(
        model_id="azure-custom-neural-professional",
        provider="azure",
        display_name="Azure Custom Neural Voice Professional",
        cost_per_m_chars=24,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2021-02-03",
    ),
    TtsModelPricing(
        model_id="azure-custom-neural-professional-hd",
        provider="azure",
        display_name="Azure Custom Neural Voice Professional HD",
        cost_per_m_chars=48,
        voice_type="hd",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-03-30",
    ),
    TtsModelPricing(
        model_id="azure-neural-standard",
        provider="azure",
        display_name="Azure Neural TTS (Standard)",
        cost_per_m_chars=15,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2019-05-04",
    ),
    TtsModelPricing(
        model_id="azure-standard-deprecated",
        provider="azure",
        display_name="Azure TTS Standard (Deprecated)",
        cost_per_m_chars=4,
        voice_type="standard",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="deprecated",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2018-11-01",
    ),
    TtsModelPricing(
        model_id="azure-tts-custom-deprecated",
        provider="azure",
        display_name="Azure TTS Custom (Deprecated)",
        cost_per_m_chars=6,
        voice_type="standard",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="deprecated",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    TtsModelPricing(
        model_id="azure-tts-custom-legacy",
        provider="azure",
        display_name="Azure TTS Custom (Deprecated)",
        cost_per_m_chars=6,
        voice_type="standard",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="deprecated",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    TtsModelPricing(
        model_id="azure-tts-custom-professional",
        provider="azure",
        display_name="Azure Custom Neural Voice Professional",
        cost_per_m_chars=24,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    TtsModelPricing(
        model_id="azure-tts-custom-professional-hd",
        provider="azure",
        display_name="Azure Custom Neural Voice Professional HD",
        cost_per_m_chars=48,
        voice_type="hd",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    TtsModelPricing(
        model_id="azure-tts-hd-v2",
        provider="azure",
        display_name="Azure TTS HD V2",
        cost_per_m_chars=30,
        voice_type=None,
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-06-01",
    ),
    TtsModelPricing(
        model_id="azure-tts-neural",
        provider="azure",
        display_name="Azure Neural TTS",
        cost_per_m_chars=15,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2019-09-01",
    ),
    TtsModelPricing(
        model_id="azure-tts-standard-deprecated",
        provider="azure",
        display_name="Azure TTS Standard (Deprecated)",
        cost_per_m_chars=4,
        voice_type="standard",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="deprecated",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    TtsModelPricing(
        model_id="azure-tts-standard-legacy",
        provider="azure",
        display_name="Azure TTS Standard (Deprecated)",
        cost_per_m_chars=4,
        voice_type="standard",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="deprecated",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    TtsModelPricing(
        model_id="cartesia-sonic-3",
        provider="cartesia",
        display_name="Cartesia Sonic-3",
        cost_per_m_chars=29.875,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-02-01",
    ),
    TtsModelPricing(
        model_id="cartesia-sonic-turbo",
        provider="cartesia",
        display_name="Cartesia Sonic-Turbo",
        cost_per_m_chars=29.875,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-03-11",
    ),
    TtsModelPricing(
        model_id="deepgram-aura-1",
        provider="deepgram",
        display_name="Deepgram Aura-1",
        cost_per_m_chars=15,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-01-01",
    ),
    TtsModelPricing(
        model_id="deepgram-aura-1-growth",
        provider="deepgram",
        display_name="Deepgram Aura-1 (Growth)",
        cost_per_m_chars=13.5,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-03-12",
    ),
    TtsModelPricing(
        model_id="deepgram-aura-1-payg",
        provider="deepgram",
        display_name="Deepgram Aura-1 (Pay As You Go)",
        cost_per_m_chars=15,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-03-12",
    ),
    TtsModelPricing(
        model_id="deepgram-aura-2",
        provider="deepgram",
        display_name="Deepgram Aura-2",
        cost_per_m_chars=30,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-01",
    ),
    TtsModelPricing(
        model_id="deepgram-aura-2-growth",
        provider="deepgram",
        display_name="Deepgram Aura-2 (Growth)",
        cost_per_m_chars=27,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-04-15",
    ),
    TtsModelPricing(
        model_id="deepgram-aura-2-payg",
        provider="deepgram",
        display_name="Deepgram Aura-2 (Pay As You Go)",
        cost_per_m_chars=30,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-04-15",
    ),
    TtsModelPricing(
        model_id="elevenlabs-flash",
        provider="elevenlabs",
        display_name="ElevenLabs Flash",
        cost_per_m_chars=80,
        voice_type=None,
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-06-01",
    ),
    TtsModelPricing(
        model_id="elevenlabs-multilingual-v2",
        provider="elevenlabs",
        display_name="ElevenLabs Multilingual v2",
        cost_per_m_chars=120,
        voice_type=None,
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-01-01",
    ),
    TtsModelPricing(
        model_id="elevenlabs-standard",
        provider="elevenlabs",
        display_name="ElevenLabs Standard",
        cost_per_m_chars=30,
        voice_type=None,
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-01-01",
    ),
    TtsModelPricing(
        model_id="elevenlabs-v3",
        provider="elevenlabs",
        display_name="ElevenLabs v3",
        cost_per_m_chars=120,
        voice_type=None,
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-04-01",
    ),
    TtsModelPricing(
        model_id="fal-chatterboxhd",
        provider="fal",
        display_name="FAL Chatterbox TTS",
        cost_per_m_chars=25,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-06-01",
    ),
    TtsModelPricing(
        model_id="fal-dia-tts",
        provider="fal",
        display_name="FAL Dia TTS",
        cost_per_m_chars=40,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-03-01",
    ),
    TtsModelPricing(
        model_id="fal-f5-tts",
        provider="fal",
        display_name="FAL F5 TTS",
        cost_per_m_chars=50,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-10-01",
    ),
    TtsModelPricing(
        model_id="fal-kokoro",
        provider="fal",
        display_name="fal Kokoro TTS (American English)",
        cost_per_m_chars=20,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-01",
    ),
    TtsModelPricing(
        model_id="fal-orpheus-tts",
        provider="fal",
        display_name="FAL Orpheus TTS",
        cost_per_m_chars=50,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-03-01",
    ),
    TtsModelPricing(
        model_id="google-cloud-chirp3-hd",
        provider="google-cloud",
        display_name="Google Cloud Chirp 3 HD",
        cost_per_m_chars=30,
        voice_type="hd",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-04-02",
    ),
    TtsModelPricing(
        model_id="google-cloud-chirp3-instant-custom",
        provider="google-cloud",
        display_name="Google Cloud Chirp 3 Instant Custom Voice",
        cost_per_m_chars=60,
        voice_type="hd",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    TtsModelPricing(
        model_id="google-cloud-instant-custom-voice",
        provider="google-cloud",
        display_name="Google Cloud Instant Custom Voice",
        cost_per_m_chars=60,
        voice_type="hd",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-04-09",
    ),
    TtsModelPricing(
        model_id="google-cloud-neural2",
        provider="google-cloud",
        display_name="Google Cloud Neural2",
        cost_per_m_chars=16,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2022-06-27",
    ),
    TtsModelPricing(
        model_id="google-cloud-polyglot",
        provider="google-cloud",
        display_name="Google Cloud Polyglot",
        cost_per_m_chars=16,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="preview",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-04-16",
    ),
    TtsModelPricing(
        model_id="google-cloud-polyglot-preview",
        provider="google-cloud",
        display_name="Google Cloud Polyglot (Preview)",
        cost_per_m_chars=16,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="preview",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-09-01",
    ),
    TtsModelPricing(
        model_id="google-cloud-standard",
        provider="google-cloud",
        display_name="Google Cloud Standard",
        cost_per_m_chars=4,
        voice_type="standard",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2018-03-27",
    ),
    TtsModelPricing(
        model_id="google-cloud-studio",
        provider="google-cloud",
        display_name="Google Cloud Studio",
        cost_per_m_chars=160,
        voice_type="hd",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-06-28",
    ),
    TtsModelPricing(
        model_id="google-cloud-tts-chirp3",
        provider="google-cloud",
        display_name="Google Cloud TTS Chirp 3 HD",
        cost_per_m_chars=30,
        voice_type="hd",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    TtsModelPricing(
        model_id="google-cloud-tts-chirp3-instant-custom",
        provider="google-cloud",
        display_name="Google Cloud Chirp 3 Instant Custom Voice",
        cost_per_m_chars=60,
        voice_type="hd",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    TtsModelPricing(
        model_id="google-cloud-tts-neural2",
        provider="google-cloud",
        display_name="Google Cloud TTS Neural2",
        cost_per_m_chars=16,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2022-06-01",
    ),
    TtsModelPricing(
        model_id="google-cloud-tts-standard",
        provider="google-cloud",
        display_name="Google Cloud TTS Standard",
        cost_per_m_chars=4,
        voice_type="standard",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2018-03-27",
    ),
    TtsModelPricing(
        model_id="google-cloud-tts-studio",
        provider="google-cloud",
        display_name="Google Cloud TTS Studio",
        cost_per_m_chars=160,
        voice_type="hd",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    TtsModelPricing(
        model_id="google-cloud-tts-wavenet",
        provider="google-cloud",
        display_name="Google Cloud TTS WaveNet",
        cost_per_m_chars=4,
        voice_type="wavenet",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2018-03-27",
    ),
    TtsModelPricing(
        model_id="google-cloud-wavenet",
        provider="google-cloud",
        display_name="Google Cloud WaveNet",
        cost_per_m_chars=4,
        voice_type="wavenet",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2018-03-27",
    ),
    TtsModelPricing(
        model_id="openai-gpt-4o-mini-tts",
        provider="openai",
        display_name="OpenAI GPT-4o Mini TTS",
        cost_per_m_chars=0.6,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    TtsModelPricing(
        model_id="openai-gpt4o-mini-tts",
        provider="openai",
        display_name="OpenAI GPT-4o Mini TTS",
        cost_per_m_chars=0.6,
        voice_type="neural",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    TtsModelPricing(
        model_id="openai-tts-1",
        provider="openai",
        display_name="OpenAI TTS-1",
        cost_per_m_chars=15,
        voice_type="standard",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-11-06",
    ),
    TtsModelPricing(
        model_id="openai-tts-1-hd",
        provider="openai",
        display_name="OpenAI TTS-1 HD",
        cost_per_m_chars=30,
        voice_type="hd",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-11-06",
    ),
    TtsModelPricing(
        model_id="openai-tts-hd",
        provider="openai",
        display_name="OpenAI TTS HD",
        cost_per_m_chars=30,
        voice_type="hd",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-11-06",
    ),
    TtsModelPricing(
        model_id="openai-tts-standard",
        provider="openai",
        display_name="OpenAI TTS",
        cost_per_m_chars=15,
        voice_type="standard",
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-11-06",
    ),
    TtsModelPricing(
        model_id="playht-2",
        provider="playht",
        display_name="PlayHT 2.0",
        cost_per_m_chars=30,
        voice_type=None,
        max_characters=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-06-01",
    ),
]
