# DO NOT EDIT — generated from registry/*.yaml by `npm run generate-static`
"""Static avatar pricing data for the PriceToken SDK."""

from __future__ import annotations

from .types import AvatarModelPricing, FreshnessInfo

STATIC_AVATAR_PRICING: list[AvatarModelPricing] = [
    AvatarModelPricing(
        model_id="fal-heygen-avatar4-i2v",
        provider="fal",
        display_name="HeyGen Photo Avatar 4 (FAL Image-to-Video)",
        cost_per_minute=6,
        avatar_type="standard",
        resolution=None,
        max_duration=None,
        quality_mode=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-05-01",
        lip_sync=True,
    ),
    AvatarModelPricing(
        model_id="fal-heygen-avatar4-twin",
        provider="fal",
        display_name="FAL HeyGen Avatar 4 Digital Twin",
        cost_per_minute=6,
        avatar_type="premium",
        resolution=None,
        max_duration=None,
        quality_mode=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-05-01",
        lip_sync=True,
    ),
    AvatarModelPricing(
        model_id="heygen-avatar-iv",
        provider="heygen",
        display_name="HeyGen Interactive Avatar IV",
        cost_per_minute=6,
        avatar_type="premium",
        resolution="1080p",
        max_duration=180,
        quality_mode="premium",
        source="seed",
        status="deprecated",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-03-01",
        lip_sync=True,
    ),
    AvatarModelPricing(
        model_id="heygen-avatar-standard",
        provider="heygen",
        display_name="HeyGen Standard Avatar",
        cost_per_minute=1.002,
        avatar_type="standard",
        resolution="1080p",
        max_duration=600,
        quality_mode="standard",
        source="seed",
        status="deprecated",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-01-15",
        lip_sync=True,
    ),
    AvatarModelPricing(
        model_id="heygen-digital-twin-iii",
        provider="heygen",
        display_name="HeyGen Digital Twin III",
        cost_per_minute=1.998,
        avatar_type="standard",
        resolution="1080p",
        max_duration=600,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-09-12",
        lip_sync=True,
    ),
    AvatarModelPricing(
        model_id="heygen-digital-twin-iv",
        provider="heygen",
        display_name="HeyGen Digital Twin IV",
        cost_per_minute=6,
        avatar_type="premium",
        resolution="1080p",
        max_duration=600,
        quality_mode="premium",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-05-01",
        lip_sync=True,
    ),
    AvatarModelPricing(
        model_id="heygen-photo-avatar-iii",
        provider="heygen",
        display_name="HeyGen Photo Avatar III",
        cost_per_minute=1.002,
        avatar_type="standard",
        resolution="1080p",
        max_duration=600,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-09-12",
        lip_sync=True,
    ),
    AvatarModelPricing(
        model_id="heygen-photo-avatar-iv",
        provider="heygen",
        display_name="HeyGen Photo Avatar IV",
        cost_per_minute=6,
        avatar_type="premium",
        resolution="1080p",
        max_duration=180,
        quality_mode="premium",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-05-01",
        lip_sync=True,
    ),
    AvatarModelPricing(
        model_id="heygen-public-avatar-iii",
        provider="heygen",
        display_name="HeyGen Public Avatar III",
        cost_per_minute=1.002,
        avatar_type="standard",
        resolution="1080p",
        max_duration=600,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-09-12",
        lip_sync=True,
    ),
    AvatarModelPricing(
        model_id="heygen-public-avatar-iv",
        provider="heygen",
        display_name="HeyGen Public Avatar IV",
        cost_per_minute=6,
        avatar_type="premium",
        resolution="1080p",
        max_duration=180,
        quality_mode="premium",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-05-01",
        lip_sync=True,
    ),
    AvatarModelPricing(
        model_id="heygen-translation-precision",
        provider="heygen",
        display_name="HeyGen Video Translation (Precision)",
        cost_per_minute=6,
        avatar_type="translation",
        resolution="1080p",
        max_duration=1800,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-11-17",
        lip_sync=True,
    ),
    AvatarModelPricing(
        model_id="heygen-translation-proofread",
        provider="heygen",
        display_name="HeyGen Video Translation (Proofread)",
        cost_per_minute=0.498,
        avatar_type="translation",
        resolution="1080p",
        max_duration=1800,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-08-01",
        lip_sync=False,
    ),
    AvatarModelPricing(
        model_id="heygen-translation-speed",
        provider="heygen",
        display_name="HeyGen Video Translation (Speed)",
        cost_per_minute=3,
        avatar_type="translation",
        resolution="1080p",
        max_duration=1800,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-11-17",
        lip_sync=False,
    ),
    AvatarModelPricing(
        model_id="runway-characters",
        provider="runway",
        display_name="Runway Characters (GWM-1 Avatars)",
        cost_per_minute=0.2,
        avatar_type="standard",
        resolution="720p",
        max_duration=None,
        quality_mode=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-09",
        lip_sync=True,
    ),
]
