# DO NOT EDIT — generated from registry/*.yaml by `npm run generate-static`
"""Static video pricing data for the PriceToken SDK."""

from __future__ import annotations

from .types import FreshnessInfo, VideoModelPricing

STATIC_VIDEO_PRICING: list[VideoModelPricing] = [
    VideoModelPricing(
        model_id="fal-cosmos2.5-720p",
        provider="fal",
        display_name="FAL Cosmos 2.5 720p",
        cost_per_minute=2.07,
        resolution="720p",
        max_duration=6,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-01-15",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="fal-kling-o3-1080p",
        provider="fal",
        display_name="FAL Kling O3 1080p",
        cost_per_minute=10.08,
        resolution="1080p",
        max_duration=15,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-02-05",
        input_type="image",
    ),
    VideoModelPricing(
        model_id="fal-kling-v3-pro-1080p",
        provider="fal",
        display_name="FAL Kling v3 Pro 1080p",
        cost_per_minute=13.44,
        resolution="1080p",
        max_duration=15,
        quality_mode="professional",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-02-05",
        input_type="image",
    ),
    VideoModelPricing(
        model_id="fal-kling2.5-turbo-1080p",
        provider="fal",
        display_name="FAL Kling 2.5 Turbo Pro 1080p",
        cost_per_minute=4.2,
        resolution="1080p",
        max_duration=10,
        quality_mode="turbo",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-09-23",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="fal-kling3-1080p",
        provider="fal",
        display_name="FAL Kling 3.0 1080p",
        cost_per_minute=10.08,
        resolution="1080p",
        max_duration=15,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-02-05",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="fal-ltx2.3-1080p",
        provider="fal",
        display_name="FAL LTX-2.3 1080p",
        cost_per_minute=3.6,
        resolution="1080p",
        max_duration=10,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-05",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="fal-ovi-720p",
        provider="fal",
        display_name="FAL Ovi Text to Video 720p",
        cost_per_minute=2.4,
        resolution="720p",
        max_duration=5,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-01",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="fal-sora2-720p",
        provider="fal",
        display_name="FAL Sora 2 720p",
        cost_per_minute=6,
        resolution="720p",
        max_duration=12,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-09-30",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="fal-sora2-pro-1080p",
        provider="fal",
        display_name="FAL Sora 2 Pro 1080p",
        cost_per_minute=30,
        resolution="1080p",
        max_duration=25,
        quality_mode="professional",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-09-30",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="fal-sora2-pro-720p",
        provider="fal",
        display_name="FAL Sora 2 Pro 720p",
        cost_per_minute=18,
        resolution="720p",
        max_duration=25,
        quality_mode="professional",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-09-30",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="fal-veo3-1080p",
        provider="fal",
        display_name="FAL Veo 3 1080p",
        cost_per_minute=30,
        resolution="1080p",
        max_duration=8,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-10-15",
        input_type="text",
    ),
    VideoModelPricing(
        model_id="fal-veo3-fast-1080p",
        provider="fal",
        display_name="FAL Veo 3 Fast 1080p",
        cost_per_minute=15,
        resolution="1080p",
        max_duration=8,
        quality_mode="turbo",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-12-01",
        input_type="text",
    ),
    VideoModelPricing(
        model_id="fal-wan2.5-480p",
        provider="fal",
        display_name="FAL WAN 2.5 480p",
        cost_per_minute=3,
        resolution="480p",
        max_duration=5,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-06-01",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="kling-3.0-1080p",
        provider="kling",
        display_name="Kling 3.0 1080p",
        cost_per_minute=5.04,
        resolution="1080p",
        max_duration=15,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-02-05",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="kling-v3-1080p",
        provider="kling",
        display_name="Kling V3 1080p",
        cost_per_minute=5.04,
        resolution="1080p",
        max_duration=15,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-01",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="kling-v3-omni-1080p",
        provider="kling",
        display_name="Kling V3 Omni 1080p",
        cost_per_minute=5.04,
        resolution="1080p",
        max_duration=15,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-01",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="kling-video-o1-1080p",
        provider="kling",
        display_name="Kling Video O1 1080p",
        cost_per_minute=5.04,
        resolution="1080p",
        max_duration=15,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-01",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="ltx-2.3-fast-1080p",
        provider="ltx",
        display_name="LTX 2.3 Fast 1080p",
        cost_per_minute=2.4,
        resolution="1080p",
        max_duration=300,
        quality_mode="turbo",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-05",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="ltx-2.3-fast-4k",
        provider="ltx",
        display_name="LTX 2.3 Fast 4K",
        cost_per_minute=9.6,
        resolution="4k",
        max_duration=300,
        quality_mode="turbo",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-05",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="ltx-2.3-pro-1080p",
        provider="ltx",
        display_name="LTX 2.3 Pro 1080p",
        cost_per_minute=3.6,
        resolution="1080p",
        max_duration=300,
        quality_mode="professional",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-05",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="ltx-2.3-pro-4k",
        provider="ltx",
        display_name="LTX 2.3 Pro 4K",
        cost_per_minute=14.4,
        resolution="4k",
        max_duration=300,
        quality_mode="professional",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-05",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="luma-ray-3.14-1080p",
        provider="luma",
        display_name="Luma Ray 3.14 1080p",
        cost_per_minute=3,
        resolution="1080p",
        max_duration=18,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="luma-ray-flash2-1080p",
        provider="luma",
        display_name="Luma Ray Flash 2 1080p",
        cost_per_minute=4.68,
        resolution="1080p",
        max_duration=9,
        quality_mode=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-01",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="luma-ray-flash2-720p",
        provider="luma",
        display_name="Luma Ray Flash 2 720p",
        cost_per_minute=2.88,
        resolution="720p",
        max_duration=9,
        quality_mode=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-01",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="luma-ray2-1080p",
        provider="luma",
        display_name="Luma Ray 2 1080p",
        cost_per_minute=10.32,
        resolution="1080p",
        max_duration=9,
        quality_mode=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-01",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="luma-ray2-720p",
        provider="luma",
        display_name="Luma Ray 2 720p",
        cost_per_minute=8.52,
        resolution="720p",
        max_duration=9,
        quality_mode=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-01",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="minimax-hailuo02-512p",
        provider="minimax",
        display_name="MiniMax Hailuo 02 512p",
        cost_per_minute=0.9,
        resolution="512p",
        max_duration=10,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-06-18",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="minimax-hailuo02-768p",
        provider="minimax",
        display_name="MiniMax Hailuo 02 / Hailuo 2.3 768p",
        cost_per_minute=3.36,
        resolution="768p",
        max_duration=10,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-06-18",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="minimax-hailuo02-pro-1080p",
        provider="minimax",
        display_name="MiniMax Hailuo 02 / Hailuo 2.3 1080p",
        cost_per_minute=4.9,
        resolution="1080p",
        max_duration=6,
        quality_mode="professional",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-06-18",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="minimax-hailuo23-fast-1080p",
        provider="minimax",
        display_name="MiniMax Hailuo 2.3 Fast 1080p",
        cost_per_minute=3.3,
        resolution="1080p",
        max_duration=6,
        quality_mode="turbo",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-10-28",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="minimax-hailuo23-fast-768p",
        provider="minimax",
        display_name="MiniMax Hailuo 2.3 Fast 768p",
        cost_per_minute=1.92,
        resolution="768p",
        max_duration=10,
        quality_mode="turbo",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-10-28",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="pika-2.5-1080p",
        provider="pika",
        display_name="Pika 2.5 1080p",
        cost_per_minute=5.49,
        resolution="1080p",
        max_duration=10,
        quality_mode=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-11-24",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="runway-gen3alpha-720p",
        provider="runway",
        display_name="Runway Gen-3 Alpha 720p",
        cost_per_minute=6,
        resolution="720p",
        max_duration=10,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-06-17",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="runway-gen4-720p",
        provider="runway",
        display_name="Runway Gen-4 720p",
        cost_per_minute=7.2,
        resolution="720p",
        max_duration=10,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-06-01",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="runway-gen4-turbo-720p",
        provider="runway",
        display_name="Runway Gen-4 Turbo 720p",
        cost_per_minute=3,
        resolution="720p",
        max_duration=10,
        quality_mode="turbo",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-06-01",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="runway-gen4.5-720p",
        provider="runway",
        display_name="Runway Gen-4.5 720p",
        cost_per_minute=15,
        resolution="720p",
        max_duration=10,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-02-01",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="seedance-1.5-pro-480p",
        provider="seedance",
        display_name="Seedance 1.5 Pro 480p (no audio)",
        cost_per_minute=2.802,
        resolution="480p",
        max_duration=10,
        quality_mode="professional",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-01-21",
        input_type="image",
    ),
    VideoModelPricing(
        model_id="seedance-1.5-pro-480p-audio",
        provider="seedance",
        display_name="Seedance 1.5 Pro 480p (with audio)",
        cost_per_minute=5.598,
        resolution="480p",
        max_duration=10,
        quality_mode="professional",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-01-21",
        input_type="image",
    ),
    VideoModelPricing(
        model_id="seedance-1.5-pro-720p",
        provider="seedance",
        display_name="Seedance 1.5 Pro 720p (no audio)",
        cost_per_minute=5.928,
        resolution="720p",
        max_duration=10,
        quality_mode="professional",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-01-21",
        input_type="image",
    ),
    VideoModelPricing(
        model_id="seedance-1.5-pro-720p-audio",
        provider="seedance",
        display_name="Seedance 1.5 Pro 720p (with audio)",
        cost_per_minute=11.856,
        resolution="720p",
        max_duration=10,
        quality_mode="professional",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-01-21",
        input_type="image",
    ),
    VideoModelPricing(
        model_id="seedance-2.0-1080p",
        provider="seedance",
        display_name="Seedance 2.0 1080p",
        cost_per_minute=4.8,
        resolution="1080p",
        max_duration=15,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-02-10",
        input_type="image",
    ),
    VideoModelPricing(
        model_id="sora2-720p",
        provider="sora",
        display_name="Sora 2 720p",
        cost_per_minute=6,
        resolution="720p",
        max_duration=20,
        quality_mode="standard",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-02-01",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="sora2-pro-1080p",
        provider="sora",
        display_name="Sora 2 Pro 1080p",
        cost_per_minute=30,
        resolution="1080p",
        max_duration=20,
        quality_mode="professional",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-02-01",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="sora2-pro-720p",
        provider="sora",
        display_name="Sora 2 Pro 720p",
        cost_per_minute=18,
        resolution="720p",
        max_duration=20,
        quality_mode="professional",
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-02-01",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="veo-3.1-1080p",
        provider="veo",
        display_name="Veo 3.1 Standard 1080p",
        cost_per_minute=24,
        resolution="1080p",
        max_duration=8,
        quality_mode="standard",
        source="seed",
        status="preview",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-12-01",
        input_type="text,image",
    ),
    VideoModelPricing(
        model_id="veo-3.1-4k",
        provider="veo",
        display_name="Veo 3.1 Standard 4K",
        cost_per_minute=36,
        resolution="4k",
        max_duration=8,
        quality_mode="standard",
        source="seed",
        status="preview",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-12-01",
        input_type="text,image",
    ),
]
