# DO NOT EDIT — generated from registry/*.yaml by `npm run generate-static`
"""Static STT pricing data for the PriceToken SDK."""

from __future__ import annotations

from .types import FreshnessInfo, SttModelPricing

STATIC_STT_PRICING: list[SttModelPricing] = [
    SttModelPricing(
        model_id="assemblyai-best",
        provider="assemblyai",
        display_name="AssemblyAI Best (Universal-3 Pro)",
        cost_per_minute=0.0035,
        stt_type="batch",
        max_duration=None,
        supported_languages=6,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-02-01",
    ),
    SttModelPricing(
        model_id="assemblyai-best-async",
        provider="assemblyai",
        display_name="AssemblyAI Best Async (Universal-3 Pro)",
        cost_per_minute=0.0035,
        stt_type="batch",
        max_duration=None,
        supported_languages=6,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    SttModelPricing(
        model_id="assemblyai-universal-2",
        provider="assemblyai",
        display_name="AssemblyAI Universal-2",
        cost_per_minute=0.0025,
        stt_type="batch",
        max_duration=None,
        supported_languages=99,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-06-01",
    ),
    SttModelPricing(
        model_id="assemblyai-universal-2-batch",
        provider="assemblyai",
        display_name="AssemblyAI Universal-2 (Pre-recorded)",
        cost_per_minute=0.0025,
        stt_type="batch",
        max_duration=None,
        supported_languages=99,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-10-31",
    ),
    SttModelPricing(
        model_id="assemblyai-universal-3-pro-batch",
        provider="assemblyai",
        display_name="AssemblyAI Universal-3 Pro (Pre-recorded)",
        cost_per_minute=0.0035,
        stt_type="batch",
        max_duration=None,
        supported_languages=6,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-02-01",
    ),
    SttModelPricing(
        model_id="assemblyai-universal-3-pro-streaming",
        provider="assemblyai",
        display_name="AssemblyAI Universal-3 Pro Streaming",
        cost_per_minute=0.0075,
        stt_type="streaming",
        max_duration=None,
        supported_languages=6,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-02-01",
    ),
    SttModelPricing(
        model_id="assemblyai-universal-streaming",
        provider="assemblyai",
        display_name="AssemblyAI Universal-Streaming",
        cost_per_minute=0.0025,
        stt_type="streaming",
        max_duration=None,
        supported_languages=1,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    SttModelPricing(
        model_id="assemblyai-universal-streaming-en",
        provider="assemblyai",
        display_name="AssemblyAI Universal-Streaming (English)",
        cost_per_minute=0.0025,
        stt_type="streaming",
        max_duration=None,
        supported_languages=1,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-06-02",
    ),
    SttModelPricing(
        model_id="assemblyai-universal-streaming-multilingual",
        provider="assemblyai",
        display_name="AssemblyAI Universal-Streaming Multilingual",
        cost_per_minute=0.0025,
        stt_type="streaming",
        max_duration=None,
        supported_languages=6,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-11-12",
    ),
    SttModelPricing(
        model_id="assemblyai-whisper-streaming",
        provider="assemblyai",
        display_name="AssemblyAI Whisper Streaming",
        cost_per_minute=0.005,
        stt_type="streaming",
        max_duration=None,
        supported_languages=99,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-11-01",
    ),
    SttModelPricing(
        model_id="azure-speech-custom-batch",
        provider="azure",
        display_name="Azure Speech Custom Batch Transcription",
        cost_per_minute=0.00375,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2018-09-24",
    ),
    SttModelPricing(
        model_id="azure-speech-custom-realtime",
        provider="azure",
        display_name="Azure Speech Custom Real-time Transcription",
        cost_per_minute=0.02,
        stt_type="real-time",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2018-09-24",
    ),
    SttModelPricing(
        model_id="azure-speech-standard-batch",
        provider="azure",
        display_name="Azure Speech Standard Batch Transcription",
        cost_per_minute=0.003,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2018-09-24",
    ),
    SttModelPricing(
        model_id="azure-speech-standard-realtime",
        provider="azure",
        display_name="Azure Speech Standard Real-time Transcription",
        cost_per_minute=0.016667,
        stt_type="real-time",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2018-09-24",
    ),
    SttModelPricing(
        model_id="azure-stt-batch",
        provider="azure",
        display_name="Azure Speech Standard Batch Transcription",
        cost_per_minute=0.003,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    SttModelPricing(
        model_id="azure-stt-custom",
        provider="azure",
        display_name="Azure Speech Custom Real-time",
        cost_per_minute=0.02,
        stt_type="real-time",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    SttModelPricing(
        model_id="azure-stt-custom-batch",
        provider="azure",
        display_name="Azure Speech Custom Batch Transcription",
        cost_per_minute=0.00375,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    SttModelPricing(
        model_id="azure-stt-realtime",
        provider="azure",
        display_name="Azure Speech Standard Real-time Transcription",
        cost_per_minute=0.016667,
        stt_type="real-time",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    SttModelPricing(
        model_id="azure-stt-standard",
        provider="azure",
        display_name="Azure Speech Standard Real-time",
        cost_per_minute=0.016667,
        stt_type="real-time",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2019-09-01",
    ),
    SttModelPricing(
        model_id="cartesia-ink",
        provider="cartesia",
        display_name="Cartesia Ink",
        cost_per_minute=0.002167,
        stt_type=None,
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-03-01",
    ),
    SttModelPricing(
        model_id="cartesia-ink-whisper",
        provider="cartesia",
        display_name="Cartesia Ink-Whisper",
        cost_per_minute=0.002167,
        stt_type="streaming",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-06-10",
    ),
    SttModelPricing(
        model_id="cartesia-ink-whisper-standard",
        provider="cartesia",
        display_name="Cartesia Ink-Whisper",
        cost_per_minute=0.002167,
        stt_type="streaming",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-06-10",
    ),
    SttModelPricing(
        model_id="deepgram-base",
        provider="deepgram",
        display_name="Deepgram Base",
        cost_per_minute=0.0145,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    SttModelPricing(
        model_id="deepgram-base-batch",
        provider="deepgram",
        display_name="Deepgram Base (Batch)",
        cost_per_minute=0.0145,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2022-07-07",
    ),
    SttModelPricing(
        model_id="deepgram-base-prerecorded",
        provider="deepgram",
        display_name="Deepgram Base (Pre-Recorded)",
        cost_per_minute=0.0145,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2022-07-07",
    ),
    SttModelPricing(
        model_id="deepgram-base-streaming",
        provider="deepgram",
        display_name="Deepgram Base (Streaming)",
        cost_per_minute=0.0145,
        stt_type="streaming",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2022-07-07",
    ),
    SttModelPricing(
        model_id="deepgram-enhanced",
        provider="deepgram",
        display_name="Deepgram Enhanced",
        cost_per_minute=0.0165,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    SttModelPricing(
        model_id="deepgram-enhanced-batch",
        provider="deepgram",
        display_name="Deepgram Enhanced (Batch)",
        cost_per_minute=0.0165,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2022-05-26",
    ),
    SttModelPricing(
        model_id="deepgram-enhanced-prerecorded",
        provider="deepgram",
        display_name="Deepgram Enhanced (Pre-Recorded)",
        cost_per_minute=0.0165,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2022-05-26",
    ),
    SttModelPricing(
        model_id="deepgram-enhanced-streaming",
        provider="deepgram",
        display_name="Deepgram Enhanced (Streaming)",
        cost_per_minute=0.0165,
        stt_type="streaming",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2022-05-26",
    ),
    SttModelPricing(
        model_id="deepgram-flux-batch",
        provider="deepgram",
        display_name="Deepgram Flux (Batch)",
        cost_per_minute=0.0077,
        stt_type="batch",
        max_duration=None,
        supported_languages=45,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-10-02",
    ),
    SttModelPricing(
        model_id="deepgram-flux-prerecorded",
        provider="deepgram",
        display_name="Deepgram Flux (Pre-Recorded)",
        cost_per_minute=0.0077,
        stt_type="batch",
        max_duration=None,
        supported_languages=45,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-10-02",
    ),
    SttModelPricing(
        model_id="deepgram-flux-streaming",
        provider="deepgram",
        display_name="Deepgram Flux (Streaming)",
        cost_per_minute=0.0077,
        stt_type="streaming",
        max_duration=None,
        supported_languages=45,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-10-02",
    ),
    SttModelPricing(
        model_id="deepgram-nova-2",
        provider="deepgram",
        display_name="Deepgram Nova-2",
        cost_per_minute=0.0058,
        stt_type="batch",
        max_duration=None,
        supported_languages=45,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-12-01",
    ),
    SttModelPricing(
        model_id="deepgram-nova-2-batch",
        provider="deepgram",
        display_name="Deepgram Nova-2 (Batch)",
        cost_per_minute=0.0058,
        stt_type="batch",
        max_duration=None,
        supported_languages=45,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-11-14",
    ),
    SttModelPricing(
        model_id="deepgram-nova-2-prerecorded",
        provider="deepgram",
        display_name="Deepgram Nova-2 (Pre-Recorded)",
        cost_per_minute=0.0058,
        stt_type="batch",
        max_duration=None,
        supported_languages=45,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-11-14",
    ),
    SttModelPricing(
        model_id="deepgram-nova-2-streaming",
        provider="deepgram",
        display_name="Deepgram Nova-2 (Streaming)",
        cost_per_minute=0.0058,
        stt_type="streaming",
        max_duration=None,
        supported_languages=45,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-11-14",
    ),
    SttModelPricing(
        model_id="deepgram-nova-3",
        provider="deepgram",
        display_name="Deepgram Nova-3",
        cost_per_minute=0.0077,
        stt_type="batch",
        max_duration=None,
        supported_languages=45,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-01",
    ),
    SttModelPricing(
        model_id="deepgram-nova-3-monolingual",
        provider="deepgram",
        display_name="Deepgram Nova-3 (Monolingual)",
        cost_per_minute=0.0077,
        stt_type="batch",
        max_duration=None,
        supported_languages=45,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    SttModelPricing(
        model_id="deepgram-nova-3-monolingual-batch",
        provider="deepgram",
        display_name="Deepgram Nova-3 Monolingual (Batch)",
        cost_per_minute=0.0077,
        stt_type="batch",
        max_duration=None,
        supported_languages=45,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-02-12",
    ),
    SttModelPricing(
        model_id="deepgram-nova-3-monolingual-prerecorded",
        provider="deepgram",
        display_name="Deepgram Nova-3 Monolingual (Pre-Recorded)",
        cost_per_minute=0.0077,
        stt_type="batch",
        max_duration=None,
        supported_languages=45,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-02-12",
    ),
    SttModelPricing(
        model_id="deepgram-nova-3-monolingual-streaming",
        provider="deepgram",
        display_name="Deepgram Nova-3 Monolingual (Streaming)",
        cost_per_minute=0.0077,
        stt_type="streaming",
        max_duration=None,
        supported_languages=45,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-02-12",
    ),
    SttModelPricing(
        model_id="deepgram-nova-3-multilingual",
        provider="deepgram",
        display_name="Deepgram Nova-3 Multilingual",
        cost_per_minute=0.0092,
        stt_type="batch",
        max_duration=None,
        supported_languages=45,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-01",
    ),
    SttModelPricing(
        model_id="deepgram-nova-3-multilingual-batch",
        provider="deepgram",
        display_name="Deepgram Nova-3 Multilingual (Batch)",
        cost_per_minute=0.0092,
        stt_type="batch",
        max_duration=None,
        supported_languages=45,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-02-12",
    ),
    SttModelPricing(
        model_id="deepgram-nova-3-multilingual-prerecorded",
        provider="deepgram",
        display_name="Deepgram Nova-3 Multilingual (Pre-Recorded)",
        cost_per_minute=0.0092,
        stt_type="batch",
        max_duration=None,
        supported_languages=45,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-02-12",
    ),
    SttModelPricing(
        model_id="deepgram-nova-3-multilingual-streaming",
        provider="deepgram",
        display_name="Deepgram Nova-3 Multilingual (Streaming)",
        cost_per_minute=0.0092,
        stt_type="streaming",
        max_duration=None,
        supported_languages=45,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-02-12",
    ),
    SttModelPricing(
        model_id="elevenlabs-scribe-v1",
        provider="elevenlabs",
        display_name="ElevenLabs Scribe v1",
        cost_per_minute=0.0067,
        stt_type=None,
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-02-01",
    ),
    SttModelPricing(
        model_id="elevenlabs-scribe-v2",
        provider="elevenlabs",
        display_name="ElevenLabs Scribe v2",
        cost_per_minute=0.0067,
        stt_type=None,
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-06-01",
    ),
    SttModelPricing(
        model_id="elevenlabs-scribe-v2-realtime",
        provider="elevenlabs",
        display_name="ElevenLabs Scribe v2 Realtime",
        cost_per_minute=0.008,
        stt_type=None,
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-09-01",
    ),
    SttModelPricing(
        model_id="google-cloud-stt-enhanced",
        provider="google-cloud",
        display_name="Google Cloud STT Enhanced",
        cost_per_minute=0.036,
        stt_type=None,
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2018-04-01",
    ),
    SttModelPricing(
        model_id="google-cloud-stt-medical-conversation",
        provider="google-cloud",
        display_name="Google Cloud Speech-to-Text Medical Conversation",
        cost_per_minute=0.078,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    SttModelPricing(
        model_id="google-cloud-stt-medical-dictation",
        provider="google-cloud",
        display_name="Google Cloud Speech-to-Text Medical Dictation",
        cost_per_minute=0.078,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    SttModelPricing(
        model_id="google-cloud-stt-standard",
        provider="google-cloud",
        display_name="Google Cloud STT Standard",
        cost_per_minute=0.024,
        stt_type=None,
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2018-04-01",
    ),
    SttModelPricing(
        model_id="google-cloud-stt-v1-medical-conversation",
        provider="google-cloud",
        display_name="Google Cloud Speech-to-Text V1 Medical Conversation",
        cost_per_minute=0.078,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2021-11-08",
    ),
    SttModelPricing(
        model_id="google-cloud-stt-v1-medical-dictation",
        provider="google-cloud",
        display_name="Google Cloud Speech-to-Text V1 Medical Dictation",
        cost_per_minute=0.078,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2021-11-08",
    ),
    SttModelPricing(
        model_id="google-cloud-stt-v1-standard-logged",
        provider="google-cloud",
        display_name="Google Cloud Speech-to-Text V1 Standard (With Data Logging)",
        cost_per_minute=0.016,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2017-04-18",
    ),
    SttModelPricing(
        model_id="google-cloud-stt-v1-standard-unlogged",
        provider="google-cloud",
        display_name="Google Cloud Speech-to-Text V1 Standard (Without Data Logging)",
        cost_per_minute=0.024,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2017-04-18",
    ),
    SttModelPricing(
        model_id="google-cloud-stt-v1-standard-with-logging",
        provider="google-cloud",
        display_name="Google Cloud Speech-to-Text V1 Standard (With Logging)",
        cost_per_minute=0.016,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2017-04-18",
    ),
    SttModelPricing(
        model_id="google-cloud-stt-v1-standard-without-logging",
        provider="google-cloud",
        display_name="Google Cloud Speech-to-Text V1 Standard (Without Logging)",
        cost_per_minute=0.024,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2017-04-18",
    ),
    SttModelPricing(
        model_id="google-cloud-stt-v2-dynamic-batch",
        provider="google-cloud",
        display_name="Google Cloud Speech-to-Text V2 Dynamic Batch",
        cost_per_minute=0.003,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-08-09",
    ),
    SttModelPricing(
        model_id="google-cloud-stt-v2-standard",
        provider="google-cloud",
        display_name="Google Cloud Speech-to-Text V2 Standard",
        cost_per_minute=0.016,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-08-09",
    ),
    SttModelPricing(
        model_id="google-cloud-stt-v2-standard-dynamic-batch",
        provider="google-cloud",
        display_name="Google Cloud Speech-to-Text V2 Standard Dynamic Batch",
        cost_per_minute=0.003,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    SttModelPricing(
        model_id="google-cloud-stt-v2-standard-tier2",
        provider="google-cloud",
        display_name="Google Cloud Speech-to-Text V2 Standard (Tier 2)",
        cost_per_minute=0.01,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-08-09",
    ),
    SttModelPricing(
        model_id="google-cloud-stt-v2-standard-tier3",
        provider="google-cloud",
        display_name="Google Cloud Speech-to-Text V2 Standard (Tier 3)",
        cost_per_minute=0.008,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-08-09",
    ),
    SttModelPricing(
        model_id="google-cloud-stt-v2-standard-tier4",
        provider="google-cloud",
        display_name="Google Cloud Speech-to-Text V2 Standard (Tier 4)",
        cost_per_minute=0.004,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-08-09",
    ),
    SttModelPricing(
        model_id="google-cloud-stt-v2-standard-tier5",
        provider="google-cloud",
        display_name="Google Cloud STT V2 Standard (2M+ min)",
        cost_per_minute=0.004,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    SttModelPricing(
        model_id="openai-gpt-4o-mini-transcribe",
        provider="openai",
        display_name="OpenAI GPT-4o Mini Transcribe",
        cost_per_minute=0.003,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-03-20",
    ),
    SttModelPricing(
        model_id="openai-gpt-4o-transcribe",
        provider="openai",
        display_name="OpenAI GPT-4o Transcribe",
        cost_per_minute=0.006,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-03-20",
    ),
    SttModelPricing(
        model_id="openai-gpt-4o-transcribe-diarize",
        provider="openai",
        display_name="OpenAI GPT-4o Transcribe with Diarization",
        cost_per_minute=0.006,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-10-18",
    ),
    SttModelPricing(
        model_id="openai-gpt4o-mini-transcribe",
        provider="openai",
        display_name="OpenAI GPT-4o Mini Transcribe",
        cost_per_minute=0.003,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-03-01",
    ),
    SttModelPricing(
        model_id="openai-gpt4o-transcribe",
        provider="openai",
        display_name="OpenAI GPT-4o Transcribe",
        cost_per_minute=0.006,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-03-01",
    ),
    SttModelPricing(
        model_id="openai-gpt4o-transcribe-diarize",
        provider="openai",
        display_name="OpenAI GPT-4o Transcribe Diarize",
        cost_per_minute=0.006,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date=None,
    ),
    SttModelPricing(
        model_id="openai-whisper-1",
        provider="openai",
        display_name="OpenAI Whisper",
        cost_per_minute=0.006,
        stt_type="batch",
        max_duration=None,
        supported_languages=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-03-01",
    ),
]
